#/usr/bin/perl -w

# draw html bars using simple data
#
# 2003-04-16 Dobrica Pavlinusic <dpavlin@rot13.org>
# for usage with PLies
#
# usage:
#
# use draw_bar.pm
# draw_bar("
# title which will be centered
# name of column[tab]2.44
# name 2	[tab]3.11
# ",
# "name of class1", "name of color class 2", ...);
#

use strict;

sub draw_bar {

my $data = shift @_;
my @css_arr = @_;

print '
<table border=0 width="80%">
';

my @names;
my @vals;
my $min_val;
my $max_val;

foreach (split(/\n+/, $data)) {
	chomp;
	next if (/^$/);
	my ($name,$value) = split(/\t+/,$_);
	push @names,$name;
	push @vals,$value;

	next if (! $value);

	# set initial value
	$min_val = $value if (! $min_val);
	$max_val = $value if (! $max_val);

	# update it to latest
	$min_val = $value if ($value < $min_val);
	$max_val = $value if ($value > $max_val);
}

my $nr = 0;
foreach my $name (@names) {
	my $val = shift @vals;
	# calculate percent from absolute value
	my $p;
	if ($val) {
		$p = int( ($val - $min_val) * 90 / ($max_val - $min_val) );
		print '
			<tr>
			<td class="'.$css_arr[$nr].'" align="right" width="10%">'.$name.'</td>
			<td width="90%">
				<table border=0 width="100%">
				<tr>
				<td class="'.$css_arr[$nr].'" width="'.($p+10).'%" align="right">'.$val.'&nbsp;</td>
				<td width="'.(90 - $p).'%">&nbsp;</td>
				</tr>
				</table>
			</td>
			</tr>
		';
		$nr++;
		$nr = 0 if ($nr > $#css_arr);
	} else {
		# move name to middle of bar
		print '
			<tr>
			<td align="center" width="100%" colspan="2"><b>'.$name.'</b></td>
			</tr>
		';
	}
}

print '
</table>
';

} # sub

1;
